/*
 * List.c
 *
 * Copyright 2007, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 *
 *Գסեꥹ
 */


#include <sys/config.h>
#include <sys/types.h>
#include <sys/param.h>
#include <lib/List.h>

#include <kern/debug.h>


//#define DEBUG_LIST 1
#ifdef DEBUG_LIST
	#define STATIC
	#define INLINE
#else
	#define STATIC	static
	#define INLINE	inline
#endif


//==================================  ===========================================

//================================== Х륤ݡ ===============================

//================================== PRIVATE ============================================

//================================== PROTECT ============================================

//================================== PUBLIC =============================================

void listConstructor(
	List *this,
	OBJECT *i_object)
{
	this->next = NULL;
	this->prev = NULL;
	this->object = i_object;
}
